==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/router/src/harness/tests/test_config_builder.cc <==
/*
  Copyright (c) 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "config_builder.h"

#include <gtest/gtest.h>

TEST(TestConfigBuilder, build_section_from_init_list) {
  EXPECT_EQ(R"([section]
foo=bar
fuz=buz

)",
            mysql_harness::ConfigBuilder::build_section(
                "section", {{"foo", "bar"}, {"fuz", "buz"}}));
}

TEST(TestConfigBuilder, build_section_from_vector) {
  EXPECT_EQ(R"([section]
foo=bar
fuz=buz

)",
            mysql_harness::ConfigBuilder::build_section(
                "section", std::vector<std::pair<std::string, std::string>>{
                               {"foo", "bar"}, {"fuz", "buz"}}));
}

TEST(TestConfigBuilder, build_section_from_map) {
  EXPECT_EQ(R"([section]
foo=bar
fuz=buz

)",
            mysql_harness::ConfigBuilder::build_section(
                "section", std::map<std::string, std::string>{{"foo", "bar"},
                                                              {"fuz", "buz"}}));
}

int main(int argc, char *argv[]) {
  ::testing::InitGoogleTest(&argc, argv);
  return RUN_ALL_TESTS();
}

==> mysql-8.0_8.0.45.orig.tar.gz: mysql-8.0.45/router/src/harness/tests/test_config_builder.cc <==
/*
  Copyright (c) 2021, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "config_builder.h"

#include <gtest/gtest.h>

TEST(TestConfigBuilder, build_section_from_init_list) {
  EXPECT_EQ(R"([section]
foo=bar
fuz=buz

)",
            mysql_harness::ConfigBuilder::build_section(
                "section", {{"foo", "bar"}, {"fuz", "buz"}}));
}

TEST(TestConfigBuilder, build_section_from_vector) {
  EXPECT_EQ(R"([section]
foo=bar
fuz=buz

)",
            mysql_harness::ConfigBuilder::build_section(
                "section", std::vector<std::pair<std::string, std::string>>{
                               {"foo", "bar"}, {"fuz", "buz"}}));
}

TEST(TestConfigBuilder, build_section_from_map) {
  EXPECT_EQ(R"([section]
foo=bar
fuz=buz

)",
            mysql_harness::ConfigBuilder::build_section(
                "section", std::map<std::string, std::string>{{"foo", "bar"},
                                                              {"fuz", "buz"}}));
}

int main(int argc, char *argv[]) {
  ::testing::InitGoogleTest(&argc, argv);
  return RUN_ALL_TESTS();
}
